data year;
  input ID $2. date :date9. AstA LbtA;
  label AstA = 'Assets Annual ($mm)'   LbtA='Liabilities Annual ($mm)';
  format date date9.  AstA LbtA  comma7.0;
datalines;
XX 30jun2014 821   281
XX 30jun2015 799   303
XX 30jun2016 804   322
YY 31dec2014 1401  904
YY 31dec2015 1427  950
YY 31dec2016 1550  962
run;

data month (drop=_:);
  input ID $2.  _base _range _start_date :date9. ;
  format date date9.;
  label SalM='Monthly Sales ($mm)'  
        CgsM='Monthly Cost of Goods Sold ($mm)';
  
  do date=_start_date by 0 until (date>=intnx('year',_start_date,3,'s'));
    SalM=   _base+_range*uniform(023458150);
    CgsM=   SalM * (.85+ .20*uniform(201980568));
    SalM=round(SalM,.1);
    CgsM=round(CgsM,.1);
    format SalM CgsM  6.1;
    output;
    date=intnx('month',date,1,'e');
  end;
datalines;
XX  30  20  30jun2014
YY  60  35  31dec2014
run;

data qtr;
  set month (keep=ID date SalM);
  SalQ=sum(ifn(_N_<3,SalM,lag2(SalM))
          ,ifn(_N_<2,SalM,lag1(SalM))
          ,SalM
          );
  drop SalM;
  if mod(_N_,3)=1;
  EmpQ=round((.975+.05*uniform(1555666))*.1*SalQ,.1);
  label SalQ='Qtrly Sales ($mm)'
        EmpQ='End of Qtr Employment (1,000)';
  format SalQ empq  6.1;
run;


data year_missing; 
  set year; 
  if not (id='XX' and year(date)=2015); 
run;

data qtr_missing;
  set qtr;
  if not (id='YY' and '31dec2015'd <=date<= '31mar2016'd);
run;
